@@ -1,85 +1,65 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="it_IT">
+<TS version="2.1" language="it">
 <context>
     <name>MXDateTime</name>
     <message>
         <location filename="../datetime.ui" line="20"/>
         <location filename="../datetime.cpp" line="596"/>
         <source>MX Date &amp; Time</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Data &amp; Ora</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="26"/>
         <source>Close</source>
-        <translation type="unfinished"></translation>
+        <translation>Chiudi</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="40"/>
         <source>Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Aiuto</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="73"/>
         <source>Apply</source>
-        <translation type="unfinished"></translation>
+        <translation>Applica</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="100"/>
         <source>About...</source>
-        <translation type="unfinished"></translation>
+        <translation>Info...</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Data &amp; Ora</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="192"/>
         <source>H:mm:ss</source>
-        <translation type="unfinished"></translation>
+        <translation>H:mm:ss</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="278"/>
         <location filename="../datetime.cpp" line="296"/>
         <location filename="../datetime.cpp" line="303"/>
         <source>Hardware Clock</source>
-        <translation type="unfinished"></translation>
+        <translation>Orologio hardware</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
-        <translation type="unfinished"></translation>
+        <translation>Strumenti Orologio hardware</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ottieni informazioni dall&apos;Orologio hardware e presentale nella casella in basso.</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../datetime.ui" line="329"/>
-        <source>Time transfer</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../datetime.ui" line="348"/>
-        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../datetime.ui" line="351"/>
-        <source>System Clock to Hardware Clock</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../datetime.ui" line="335"/>
-        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
-        <translation type="unfinished"></translation>
+        <translation>Leggi l&apos;Orologio hardware</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="303"/>
@@ -91,10 +71,30 @@
         <source>Drift Adjust</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../datetime.ui" line="329"/>
+        <source>Time transfer</source>
+        <translation>Trasferimento del tempo</translation>
+    </message>
+    <message>
+        <location filename="../datetime.ui" line="335"/>
+        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
+        <translation>Imposta immediatamente l&apos;Orologio di sistema in modo che corrisponda all&apos;ora corrente registrata dall&apos;Orologio hardware.</translation>
+    </message>
     <message>
         <location filename="../datetime.ui" line="338"/>
         <source>Hardware Clock to System Clock</source>
-        <translation type="unfinished"></translation>
+        <translation>Orologio hardware a Orologio di sistema</translation>
+    </message>
+    <message>
+        <location filename="../datetime.ui" line="348"/>
+        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
+        <translation>Imposta immediatamente l&apos;Orologio hardware in modo che corrisponda all&apos;ora corrente registrata dall&apos;orologio di sistema.</translation>
+    </message>
+    <message>
+        <location filename="../datetime.ui" line="351"/>
+        <source>System Clock to Hardware Clock</source>
+        <translation>Orologio di sistema a Orologio hardware</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="361"/>
@@ -109,92 +109,92 @@
     <message>
         <location filename="../datetime.ui" line="374"/>
         <source>Time zone for the Hardware Clock</source>
-        <translation type="unfinished"></translation>
+        <translation>Fuso orario per l&apos;Orologio hardware</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="380"/>
         <source>Local time</source>
-        <translation type="unfinished"></translation>
+        <translation>Ora locale</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="383"/>
         <source>Local</source>
-        <translation type="unfinished"></translation>
+        <translation>Locale</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="390"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
-        <translation type="unfinished"></translation>
+        <translation>Tempo Coordinato Universalmente (o Tempo del Meridiano di Greenwich)</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="393"/>
         <source>UTC</source>
-        <translation type="unfinished"></translation>
+        <translation>UTC</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="433"/>
         <source>Network Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Tempo di rete</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="439"/>
         <source>Move the selected item down</source>
-        <translation type="unfinished"></translation>
+        <translation>Sposta l&apos;elemento selezionato verso il basso</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="450"/>
         <source>Move the selected item up</source>
-        <translation type="unfinished"></translation>
+        <translation>Sposta l&apos;elemento selezionato verso l&apos;alto</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="461"/>
         <source>Remove the current item from the list</source>
-        <translation type="unfinished"></translation>
+        <translation>Rimuovi l&apos;elemento corrente dall&apos;elenco</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="472"/>
         <source>Add an item to the list</source>
-        <translation type="unfinished"></translation>
+        <translation>Aggiungi un elemento all&apos;elenco</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="498"/>
         <source>Automatically update the System Clock with NTP servers:</source>
-        <translation type="unfinished"></translation>
+        <translation>Aggiorna automaticamente l&apos;Orologio di sistema con i server NTP:</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="505"/>
         <source>Immediately update the system clock with NTP servers.</source>
-        <translation type="unfinished"></translation>
+        <translation>Aggiorna immediatamente l&apos;Orologio di sistema con i server NTP.</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="508"/>
         <source>Update Now</source>
-        <translation type="unfinished"></translation>
+        <translation>Aggiorna adesso</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="520"/>
         <source>List of NTP servers to use.</source>
-        <translation type="unfinished"></translation>
+        <translation>Elenco di server NTP da usare.</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="536"/>
         <source>Type</source>
-        <translation type="unfinished"></translation>
+        <translation>Tipo</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="541"/>
         <source>Address</source>
-        <translation type="unfinished"></translation>
+        <translation>Indirizzo</translation>
     </message>
     <message>
         <location filename="../datetime.ui" line="546"/>
         <source>Options</source>
-        <translation type="unfinished"></translation>
+        <translation>Opzioni</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="270"/>
         <source>Reading...</source>
-        <translation type="unfinished"></translation>
+        <translation>Leggo...</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="284"/>
@@ -220,63 +220,63 @@
     <message>
         <location filename="../datetime.cpp" line="350"/>
         <source>Updating...</source>
-        <translation type="unfinished"></translation>
+        <translation>Aggiorno...</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="360"/>
         <source>The system clock was updated successfully.</source>
-        <translation type="unfinished"></translation>
+        <translation>L&apos;orologio di sistema è stato aggiornato correttamente.</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="362"/>
         <source>The system clock could not be updated.</source>
-        <translation type="unfinished"></translation>
+        <translation>L&apos;orologio di sistema non può essere aggiornato.</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="364"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nessuno dei server NTP nell&apos;elenco è attualmente abilitato.</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="595"/>
         <source>About MX Date &amp; Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Informazioni su MX Data &amp; Ora</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="596"/>
         <source>Version: </source>
-        <translation type="unfinished"></translation>
+        <translation>Versione: </translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="597"/>
         <source>GUI program for setting the time and date in MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>Programma di interfaccia grafica per l&apos;impostazione di data e ora in MX Linux</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="599"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="600"/>
         <location filename="../datetime.cpp" line="614"/>
         <source>License</source>
-        <translation type="unfinished"></translation>
+        <translation>Licenza</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="601"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation>Registro delle modifiche</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="602"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Annulla</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="628"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Chiudi</translation>
     </message>
     <message>
         <location filename="../datetime.cpp" line="646"/>
